@@ -180,7 +180,8 @@ base_scalar <- sql_translator(
   pmin = sql_aggregate_n("LEAST", "pmin"),
   pmax = sql_aggregate_n("GREATEST", "pmax"),
 
-  `%>%` = `%>%`,
+  # Copied onLoad
+  `%>%` = NULL,
 
   # lubridate ---------------------------------------------------------------
   # https://en.wikibooks.org/wiki/SQL_Dialects_Reference/Functions_and_expressions/Date_and_time_functions
@@ -230,7 +231,6 @@ base_scalar <- sql_translator(
   str_c = sql_paste(""),
   str_sub = sql_str_sub("SUBSTR"),
 
-  str_c = sql_not_supported("str_c()"),
   str_conv = sql_not_supported("str_conv()"),
   str_count = sql_not_supported("str_count()"),
   str_detect = sql_not_supported("str_detect()"),
