@@ -13,13 +13,14 @@ if (test_srcs$length() == 0) {
       password = "password"
     )
   } else if (identical(Sys.getenv("GITHUB_MSSQL"), "true")) {
-    if (packageVersion("odbc") >= "1.2.2.9000") {
-      test_register_con("mssql", odbc::odbc(),
-        dsn = "mssql-test-ms",
-        UID = "kirill",
-        PWD = "Password12"
-      )
-    }
+    test_register_con("mssql", odbc::odbc(),
+      driver = "ODBC Driver 17 for SQL Server",
+      database = "test",
+      uid = "SA",
+      pwd = "Password12",
+      server = "localhost",
+      port = 1433
+    )
   } else if (on_gha() || on_cran()) {
     # Only test with sqlite
   } else  {
@@ -36,12 +37,6 @@ if (test_srcs$length() == 0) {
   }
 }
 
-
-skip_if_no_db <- function(db) {
-  if (!test_srcs$has(db))
-    skip(paste0("No ", db))
-}
-
 sqlite_con_with_aux <- function() {
   tmp <- tempfile()
 
